summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:07:30 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:07:30 -0600
commite72ae02c2425f7f2c257523b8faf735335402d10 (patch)
treea61e7dc054de87194f7e5f523c71f4518845a7af
parent2a5a604bb461bace63f4bbcbf3c1d952bc792c29 (diff)
downloadkeep-e72ae02c.tar.gz
keep-e72ae02c.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
-rw-r--r--keep/app/keepmainwindow.cpp6
-rw-r--r--keep/common/backupconfig.cpp2
-rw-r--r--keep/common/backupconfig.h2
3 files changed, 5 insertions, 5 deletions
diff --git a/keep/common/backupconfig.cpp b/keep/common/backupconfig.cpp
index f029292..d6fd999 100644
--- a/keep/common/backupconfig.cpp
+++ b/keep/common/backupconfig.cpp
@@ -22,7 +22,7 @@
BackupConfig::BackupConfig()
{
- m_config = new KConfig( "keepbackuplist.rc", false );
+ m_config = new TDEConfig( "keepbackuplist.rc", false );
}
BackupConfig::~BackupConfig()
diff --git a/keep/common/backupconfig.h b/keep/common/backupconfig.h
index 32a55ba..166e4ca 100644
--- a/keep/common/backupconfig.h
+++ b/keep/common/backupconfig.h
@@ -36,7 +36,7 @@ public:
void setBackupList(TQValueList<Backup> backups);
private:
- KConfig *m_config;
+ TDEConfig *m_config;
int generateId();
};
diff --git a/keep/app/keepmainwindow.cpp b/keep/app/keepmainwindow.cpp
index ead0bc0..f8e670c 100644
--- a/keep/app/keepmainwindow.cpp
+++ b/keep/app/keepmainwindow.cpp
@@ -154,11 +154,11 @@ void KeepMainWindow::slotConfigure()
//An instance of your dialog could be already created and could be cached,
//in which case you want to display the cached dialog instead of creating
//another one
- if ( KConfigDialog::showDialog( "settings" ) )
+ if ( TDEConfigDialog::showDialog( "settings" ) )
return;
- //KConfigDialog didn't find an instance of this dialog, so lets create it :
- KConfigDialog* dialog = new KConfigDialog( this, "settings", KeepSettings::self() );
+ //TDEConfigDialog didn't find an instance of this dialog, so lets create it :
+ TDEConfigDialog* dialog = new TDEConfigDialog( this, "settings", KeepSettings::self() );
GeneralConfigView* generalConfigView = new GeneralConfigView( 0, "generalConfigView" );
dialog->addPage( generalConfigView, i18n("General"), "general" );